# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: function/log/proto/system_log.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#function/log/proto/system_log.proto\"\x89\x02\n\nLogRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0e\n\x06module\x18\x02 \x01(\t\x12\x11\n\tsubmodule\x18\x03 \x01(\t\x12\x0c\n\x04item\x18\x04 \x01(\t\x12\x0e\n\x06method\x18\x05 \x01(\t\x12\x13\n\x0bstatus_code\x18\x06 \x01(\t\x12\x14\n\x0cmessage_code\x18\x07 \x01(\t\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\x15\n\rresponse_size\x18\t \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\x12\n\n\x02ip\x18\x0b \x01(\t\x12\x0f\n\x07\x61pi_url\x18\x0c \x01(\t\x12\x14\n\x0cquery_params\x18\r \x01(\t\x12\x10\n\x08web_path\x18\x0e \x01(\t\"\x1e\n\x0bLogResponse\x12\x0f\n\x07message\x18\x01 \x01(\t29\n\x10SystemLogService\x12%\n\x08WriteLog\x12\x0b.LogRequest\x1a\x0c.LogResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'function.log.proto.system_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGREQUEST']._serialized_start=40
  _globals['_LOGREQUEST']._serialized_end=305
  _globals['_LOGRESPONSE']._serialized_start=307
  _globals['_LOGRESPONSE']._serialized_end=337
  _globals['_SYSTEMLOGSERVICE']._serialized_start=339
  _globals['_SYSTEMLOGSERVICE']._serialized_end=396
# @@protoc_insertion_point(module_scope)
